@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for busybox
@@ -6,7 +8,7 @@ CVE checker for busybox
 https://www.cvedetails.com/product/7452/Busybox-Busybox.html?vendor_id=4282
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class BusyboxChecker(Checker):
