@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for bzip2
@@ -6,7 +8,7 @@ CVE checker for bzip2
 https://www.cvedetails.com/vulnerability-list/vendor_id-1198/product_id-2068/Bzip-Bzip2.html
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class Bzip2Checker(Checker):
