@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for dovecot
@@ -6,7 +8,7 @@ CVE checker for dovecot
 https://www.cvedetails.com/product/10948/Dovecot-Dovecot.html?vendor_id=6485
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class DovecotChecker(Checker):
