@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 # pylint: disable=anomalous-backslash-in-string, invalid-name
 r"""
 CVE checker for libexpat
@@ -27,7 +29,7 @@ Release 2.2.1 Sat June 17 2017
 (etc.)
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class ExpatChecker(Checker):
