@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for ffmpeg
@@ -9,7 +11,7 @@ https://www.cvedetails.com/vulnerability-list/vendor_id-3611/Ffmpeg.html
 
 Note: Some of the "first vulnerable in" data may not be entered correctly.
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class FfmpegChecker(Checker):
