@@ -1,10 +1,12 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for libdb (berkeley db)
 CVE list: https://www.cvedetails.com/vulnerability-list/vendor_id-93/product_id-32070/Oracle-Berkeley-Db.html
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class LibdbChecker(Checker):
