@@ -1,10 +1,13 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 # pylint: disable=invalid-name
 """
 CVE checker for libgcrypt
 
 https://www.cvedetails.com/product/25777/Gnupg-Libgcrypt.html?vendor_id=4711
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class LibgcryptChecker(Checker):
