@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 # pylint: disable=invalid-name
 
 """
@@ -10,7 +12,7 @@ with loading the checker.
 References:
 https://www.cvedetails.com/vulnerability-list/vendor_id-17075/product_id-40849/Libjpeg-turbo-Libjpeg-turbo.html
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class LibjpegChecker(Checker):
