@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for mysql CLI
@@ -6,7 +8,7 @@ References:
 https://www.mysql.com/
 https://www.cvedetails.com/vulnerability-list/vendor_id-93/product_id-21801/Oracle-Mysql.html
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class MysqlChecker(Checker):
@@ -26,5 +28,5 @@ class MysqlChecker(Checker):
         r"mysql-bench",
         r"dovecot-mysql",
     ]
-    VERSION_PATTERNS = [r"mysql\-([0-9]+\.[0-9]+\-[0-9]+\.[0-9]+\.[0-9]+)"]
+    VERSION_PATTERNS = [r"mysql\-[0-9]+\.[0-9]+\-([0-9]+\.[0-9]+\.[0-9]+)"]
     VENDOR_PRODUCT = [("oracle", "mysql"), ("mysql", "mysql")]
