@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for Ncurses
@@ -9,7 +11,7 @@ https://www.cvedetails.com/vulnerability-list/vendor_id-72/product_id-38464/GNU-
 RSS feed: http://www.cvedetails.com/vulnerability-feed.php?vendor_id=72&product_id=38464&version_id=0&orderby=3&cvssscoremin=0
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class NcursesChecker(Checker):
