@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for openssh
@@ -6,7 +8,7 @@ CVE checker for openssh
 References:
 https://www.cvedetails.com/product/585/Openbsd-Openssh.html?vendor_id=97
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class OpensshChecker(Checker):
