@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for samba
@@ -11,7 +13,7 @@ But these files do not have the strings which match the signatures in regex.
 That is why they have not been added in FILENAME_PATTERNS. 
 
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class SambaChecker(Checker):
