@@ -1,4 +1,6 @@
-#!/usr/bin/python3
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 
 """
 CVE checker for sqlite
@@ -9,18 +11,17 @@ SQLLite version/sha1 data from https://www.sqlite.org/changes.html
 CVE list: https://www.cvedetails.com/vulnerability-list/vendor_id-9237/product_id-16355/Sqlite-Sqlite.html
 
 """
-from ..log import LOGGER
-
 import re
-import urllib.request as request
 import urllib.error as error
+import urllib.request as request
 
-from ..version_signature import VersionSignatureDb
-from . import Checker
+from cve_bin_tool.checkers import Checker
+from cve_bin_tool.log import LOGGER
+from cve_bin_tool.version_signature import VersionSignatureDb
 
 
 def get_version_map():
-    """ Read changelog and get SQLITE_SOURCE_ID to use for versions """
+    """Read changelog and get SQLITE_SOURCE_ID to use for versions"""
     version_map = []
 
     changeurl = "https://www.sqlite.org/changes.html"
@@ -60,7 +61,10 @@ class SqliteChecker(Checker):
         r"SQLite version %s",
     ]
     VENDOR_PRODUCT = [("sqlite", "sqlite")]
-    VERSION_PATTERNS = [r"Id: SQLite version (\d+\.\d+\.\d+)", r"sqlite(\d+)\.debug"]
+    VERSION_PATTERNS = [
+        r"Id: SQLite version (\d+\.\d+\.\d+)",
+        r"sqlite(\d+)\.debug",
+    ]  # patterns like the second one aren't ideal (check the end of the file)
     FILENAME_PATTERNS = [r"sqlite", r"sqlite3"]
 
     mapdb = VersionSignatureDb("sqlite", get_version_map, 30)
@@ -97,3 +101,10 @@ class SqliteChecker(Checker):
                     version_info["version"] = mapping[0]
 
         return version_info
+
+
+"""
+Using filenames (containing patterns like '.so' etc.) in the binaries as VERSION_PATTERNS aren't ideal.
+The reason behind this is that these might depend on who packages the file (like it 
+might work on fedora but not on ubuntu)
+"""
