@@ -1,5 +1,7 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 # pylint: disable=invalid-name
-#!/usr/bin/python3
 
 """
 CVE checker for libxerces
@@ -9,7 +11,7 @@ http://www.cvedetails.com/vulnerability-list/vendor_id-45/product_id-4103/Apache
 
 RSS feed: http://www.cvedetails.com/vulnerability-feed.php?vendor_id=45&product_id=4103&version_id=&orderby=2&cvssscoremin=0
 """
-from . import Checker
+from cve_bin_tool.checkers import Checker
 
 
 class XercesChecker(Checker):
