@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 mapping_test_data = [
     {"product": "curl", "version": "7.34.0", "version_strings": ["curl 7.34.0"]}
 ]
@@ -9,9 +12,9 @@ package_test_data = [
         "version": "7.32.0",
     },
     {
-        "url": "https://rpmfind.net/linux/openmandriva/4.0/repository/aarch64/main/release/",
-        "package_name": "curl-7.65.0-2-omv4000.aarch64.rpm",
+        "url": "http://www.rpmfind.net/linux/fedora/linux/development/rawhide/Everything/aarch64/os/Packages/c/",
+        "package_name": "curl-7.74.0-2.fc34.aarch64.rpm",
         "product": "curl",
-        "version": "7.65.0",
+        "version": "7.74.0",
     },
 ]
