@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 mapping_test_data = [
     {
         "product": "icecast",
@@ -13,9 +16,9 @@ package_test_data = [
         "version": "2.3.1",
     },
     {
-        "url": "https://mirrors.kernel.org/mageia/distrib/4/x86_64/media/core/release/",
-        "package_name": "icecast-2.3.2-8.mga4.x86_64.rpm",
+        "url": "http://www.rpmfind.net/linux/fedora/linux/development/rawhide/Everything/aarch64/os/Packages/i//",
+        "package_name": "icecast-2.4.4-6.fc34.aarch64.rpm",
         "product": "icecast",
-        "version": "2.3.2",
+        "version": "2.4.4",
     },
 ]
