@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 mapping_test_data = [
     {"product": "samba", "version": "4.10.2", "version_strings": ["SAMBA_4.10.2"]}
 ]
@@ -9,9 +12,9 @@ package_test_data = [
         "version": "4.10.4",
     },
     {
-        "url": "https://rpmfind.net/linux/openmandriva/4.0/repository/x86_64/main/release/",
-        "package_name": "samba-client-4.10.3-1-omv4000.x86_64.rpm",
+        "url": "http://www.rpmfind.net/linux/fedora/linux/development/rawhide/Everything/aarch64/os/Packages/s/",
+        "package_name": "samba-4.13.3-1.fc34.aarch64.rpm",
         "product": "samba",
-        "version": "4.10.3",
+        "version": "4.13.3",
     },
 ]
