@@ -1,3 +1,6 @@
+# Copyright (C) 2021 Intel Corporation
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 mapping_test_data = [
     {
         "product": "wireshark",
@@ -14,7 +17,7 @@ package_test_data = [
     },
     {
         "url": "http://mirror.centos.org/centos/7/os/x86_64/Packages/",
-        "package_name": "wireshark-1.10.14-24.el7.x86_64.rpm",
+        "package_name": "wireshark-1.10.14-25.el7.i686.rpm",
         "product": "wireshark",
         "version": "1.10.14",
     },
