@@ -26,6 +26,14 @@ CAB_TEST_FILE_PATH = os.path.join(
     os.path.join(os.path.abspath(os.path.dirname(__file__)), "assets"),
     "cab-test-python3.8.cab",
 )
+BAD_EXE_FILE = os.path.join(
+    os.path.join(os.path.abspath(os.path.dirname(__file__)), "assets"),
+    "empty-file.exe",
+)
+BAD_ZIP_FILE = os.path.join(
+    os.path.join(os.path.abspath(os.path.dirname(__file__)), "assets"),
+    "empty-file.zip",
+)
 
 
 class TestExtractorBase:
@@ -216,3 +224,12 @@ class TestExtractFileZip(TestExtractorBase):
             ]
         ):
             assert os.path.isdir(path)
+
+    @pytest.mark.asyncio
+    async def test_bad_zip(self):
+        """Test handling of invalid zip files.  No errors should be raised.
+        Log messages differ for .exe and .zip and are tested in test_cli.py
+        """
+
+        self.extract_files(BAD_EXE_FILE)
+        self.extract_files(BAD_ZIP_FILE)
