@@ -27,7 +27,9 @@ class TestStrings:
         """Helper function to parse a binary file and check whether
         the given string is in the parsed result"""
         self.strings.filename = os.path.join(ASSETS_PATH, filename)
-        binutils_strings, _ = await aio_run_command(["strings", self.strings.filename])
+        binutils_strings, _, _ = await aio_run_command(
+            ["strings", self.strings.filename]
+        )
         ours = await self.strings.aio_parse()
         for theirs in binutils_strings.splitlines():
             assert theirs.decode("utf-8") in ours
